8202334: Update javax.lang.model.util visitors for 11
authordarcy
Tue, 01 May 2018 17:19:18 -0700
changeset 49941 2f0c14b69efa
parent 49940 516128be1a80
child 49942 f4310c01104d
8202334: Update javax.lang.model.util visitors for 11 Reviewed-by: jjg
src/java.compiler/share/classes/javax/lang/model/util/AbstractAnnotationValueVisitor9.java
src/java.compiler/share/classes/javax/lang/model/util/AbstractElementVisitor9.java
src/java.compiler/share/classes/javax/lang/model/util/AbstractTypeVisitor9.java
src/java.compiler/share/classes/javax/lang/model/util/ElementKindVisitor9.java
src/java.compiler/share/classes/javax/lang/model/util/ElementScanner9.java
src/java.compiler/share/classes/javax/lang/model/util/SimpleAnnotationValueVisitor9.java
src/java.compiler/share/classes/javax/lang/model/util/SimpleElementVisitor9.java
src/java.compiler/share/classes/javax/lang/model/util/SimpleTypeVisitor9.java
src/java.compiler/share/classes/javax/lang/model/util/TypeKindVisitor9.java
--- a/src/java.compiler/share/classes/javax/lang/model/util/AbstractAnnotationValueVisitor9.java	Tue May 01 14:40:31 2018 -0700
+++ b/src/java.compiler/share/classes/javax/lang/model/util/AbstractAnnotationValueVisitor9.java	Tue May 01 17:19:18 2018 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -31,8 +31,8 @@
 
 /**
  * A skeletal visitor for annotation values with default behavior
  * appropriate for the {@link SourceVersion#RELEASE_9 RELEASE_9}
  * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
  *
  * <p> <b>WARNING:</b> The {@code AnnotationValueVisitor} interface
  * implemented by this class may have methods added to it in the
@@ -59,7 +59,7 @@
  * @see AbstractAnnotationValueVisitor8
  * @since 9
  */
-@SupportedSourceVersion(RELEASE_10)
+@SupportedSourceVersion(RELEASE_11)
 public abstract class AbstractAnnotationValueVisitor9<R, P> extends AbstractAnnotationValueVisitor8<R, P> {
 
     /**
@@ -31,8 +31,8 @@
 /**
  * A skeletal visitor for annotation values with default behavior
- * appropriate for the {@link SourceVersion#RELEASE_9 RELEASE_9}
- * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
+ * appropriate for source versions {@link SourceVersion#RELEASE_9
+ * RELEASE_9} through {@link SourceVersion#RELEASE_11 RELEASE_11}.
  *
  * <p> <b>WARNING:</b> The {@code AnnotationValueVisitor} interface
--- a/src/java.compiler/share/classes/javax/lang/model/util/AbstractElementVisitor9.java	Tue May 01 14:40:31 2018 -0700
+++ b/src/java.compiler/share/classes/javax/lang/model/util/AbstractElementVisitor9.java	Tue May 01 17:19:18 2018 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -33,8 +33,8 @@
 
 /**
  * A skeletal visitor of program elements with default behavior
  * appropriate for the {@link SourceVersion#RELEASE_9 RELEASE_9}
  * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
  *
  * <p> <b>WARNING:</b> The {@code ElementVisitor} interface
  * implemented by this class may have methods added to it in the
@@ -65,7 +65,7 @@
  * @since 9
  * @spec JPMS
  */
-@SupportedSourceVersion(RELEASE_10)
+@SupportedSourceVersion(RELEASE_11)
 public abstract class AbstractElementVisitor9<R, P> extends AbstractElementVisitor8<R, P> {
     /**
      * Constructor for concrete subclasses to call.
@@ -33,8 +33,8 @@
 /**
  * A skeletal visitor of program elements with default behavior
- * appropriate for the {@link SourceVersion#RELEASE_9 RELEASE_9}
- * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
+ * appropriate for source versions {@link SourceVersion#RELEASE_9
+ * RELEASE_9} through {@link SourceVersion#RELEASE_11 RELEASE_11}.
  *
  * <p> <b>WARNING:</b> The {@code ElementVisitor} interface
--- a/src/java.compiler/share/classes/javax/lang/model/util/AbstractTypeVisitor9.java	Tue May 01 14:40:31 2018 -0700
+++ b/src/java.compiler/share/classes/javax/lang/model/util/AbstractTypeVisitor9.java	Tue May 01 17:19:18 2018 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -32,8 +32,8 @@
 
 /**
  * A skeletal visitor of types with default behavior appropriate for
  * the {@link SourceVersion#RELEASE_9 RELEASE_9}
  * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
  *
  * <p> <b>WARNING:</b> The {@code TypeVisitor} interface implemented
  * by this class may have methods added to it in the future to
@@ -63,7 +63,7 @@
  * @see AbstractTypeVisitor8
  * @since 9
  */
-@SupportedSourceVersion(RELEASE_10)
+@SupportedSourceVersion(RELEASE_11)
 public abstract class AbstractTypeVisitor9<R, P> extends AbstractTypeVisitor8<R, P> {
     /**
      * Constructor for concrete subclasses to call.
@@ -32,8 +32,8 @@
 /**
  * A skeletal visitor of types with default behavior appropriate for
- * the {@link SourceVersion#RELEASE_9 RELEASE_9}
- * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
+ * source versions {@link SourceVersion#RELEASE_9 RELEASE_9} through
+ * {@link SourceVersion#RELEASE_11 RELEASE_11}.
  *
  * <p> <b>WARNING:</b> The {@code TypeVisitor} interface implemented
--- a/src/java.compiler/share/classes/javax/lang/model/util/ElementKindVisitor9.java	Tue May 01 14:40:31 2018 -0700
+++ b/src/java.compiler/share/classes/javax/lang/model/util/ElementKindVisitor9.java	Tue May 01 17:19:18 2018 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -32,9 +32,11 @@
 
 /**
  * A visitor of program elements based on their {@linkplain
  * ElementKind kind} with default behavior appropriate for the {@link
  * SourceVersion#RELEASE_9 RELEASE_9} and {@link
  * SourceVersion#RELEASE_10 RELEASE_10} source versions. For {@linkplain
  * Element elements} <code><i>Xyz</i></code> that may have more than one
  * kind, the <code>visit<i>Xyz</i></code> methods in this class delegate
  * to the <code>visit<i>Xyz</i>As<i>Kind</i></code> method corresponding to the
@@ -78,7 +80,7 @@
  * @since 9
  * @spec JPMS
  */
-@SupportedSourceVersion(RELEASE_10)
+@SupportedSourceVersion(RELEASE_11)
 public class ElementKindVisitor9<R, P> extends ElementKindVisitor8<R, P> {
     /**
      * Constructor for concrete subclasses; uses {@code null} for the
@@ -32,9 +32,11 @@
 /**
  * A visitor of program elements based on their {@linkplain
- * ElementKind kind} with default behavior appropriate for the {@link
- * SourceVersion#RELEASE_9 RELEASE_9} and {@link
- * SourceVersion#RELEASE_10 RELEASE_10} source versions. For {@linkplain
+ * ElementKind kind} with default behavior appropriate for source
+ * versions {@link SourceVersion#RELEASE_9 RELEASE_9} through {@link
+ * SourceVersion#RELEASE_11 RELEASE_11}.
+ *
+ * For {@linkplain
  * Element elements} <code><i>Xyz</i></code> that may have more than one
  * kind, the <code>visit<i>Xyz</i></code> methods in this class delegate
--- a/src/java.compiler/share/classes/javax/lang/model/util/ElementScanner9.java	Tue May 01 14:40:31 2018 -0700
+++ b/src/java.compiler/share/classes/javax/lang/model/util/ElementScanner9.java	Tue May 01 17:19:18 2018 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -33,8 +33,9 @@
 
 /**
  * A scanning visitor of program elements with default behavior
  * appropriate for the {@link SourceVersion#RELEASE_9 RELEASE_9}
  * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
  * The <code>visit<i>Xyz</i></code> methods in this
  * class scan their component elements by calling {@code scan} on
  * their {@linkplain Element#getEnclosedElements enclosed elements},
@@ -91,7 +92,7 @@
  * @since 9
  * @spec JPMS
  */
-@SupportedSourceVersion(RELEASE_10)
+@SupportedSourceVersion(RELEASE_11)
 public class ElementScanner9<R, P> extends ElementScanner8<R, P> {
     /**
      * Constructor for concrete subclasses; uses {@code null} for the
@@ -33,8 +33,9 @@
 /**
  * A scanning visitor of program elements with default behavior
- * appropriate for the {@link SourceVersion#RELEASE_9 RELEASE_9}
- * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
+ * appropriate for source versions {@link SourceVersion#RELEASE_9
+ * RELEASE_9} through {@link SourceVersion#RELEASE_11 RELEASE_11}.
+ *
  * The <code>visit<i>Xyz</i></code> methods in this
  * class scan their component elements by calling {@code scan} on
--- a/src/java.compiler/share/classes/javax/lang/model/util/SimpleAnnotationValueVisitor9.java	Tue May 01 14:40:31 2018 -0700
+++ b/src/java.compiler/share/classes/javax/lang/model/util/SimpleAnnotationValueVisitor9.java	Tue May 01 17:19:18 2018 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -31,8 +31,9 @@
 
 /**
  * A simple visitor for annotation values with default behavior
  * appropriate for the {@link SourceVersion#RELEASE_9 RELEASE_9}
  * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
  * Visit methods call {@link #defaultAction
  * defaultAction} passing their arguments to {@code defaultAction}'s
  * corresponding parameters.
@@ -67,7 +68,7 @@
  * @see SimpleAnnotationValueVisitor8
  * @since 9
  */
-@SupportedSourceVersion(RELEASE_10)
+@SupportedSourceVersion(RELEASE_11)
 public class SimpleAnnotationValueVisitor9<R, P> extends SimpleAnnotationValueVisitor8<R, P> {
     /**
      * Constructor for concrete subclasses; uses {@code null} for the
@@ -31,8 +31,9 @@
 /**
  * A simple visitor for annotation values with default behavior
- * appropriate for the {@link SourceVersion#RELEASE_9 RELEASE_9}
- * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
+ * appropriate for source versions {@link SourceVersion#RELEASE_9
+ * RELEASE_9} through {@link SourceVersion#RELEASE_11 RELEASE_11}.
+ *
  * Visit methods call {@link #defaultAction
  * defaultAction} passing their arguments to {@code defaultAction}'s
--- a/src/java.compiler/share/classes/javax/lang/model/util/SimpleElementVisitor9.java	Tue May 01 14:40:31 2018 -0700
+++ b/src/java.compiler/share/classes/javax/lang/model/util/SimpleElementVisitor9.java	Tue May 01 17:19:18 2018 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -32,8 +32,8 @@
 
 /**
  * A simple visitor of program elements with default behavior
  * appropriate for the {@link SourceVersion#RELEASE_9 RELEASE_9}
  * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
  *
  * Visit methods corresponding to {@code RELEASE_9} and earlier
  * language constructs call {@link #defaultAction defaultAction},
@@ -73,7 +73,7 @@
  * @since 9
  * @spec JPMS
  */
-@SupportedSourceVersion(RELEASE_10)
+@SupportedSourceVersion(RELEASE_11)
 public class SimpleElementVisitor9<R, P> extends SimpleElementVisitor8<R, P> {
     /**
      * Constructor for concrete subclasses; uses {@code null} for the
@@ -32,8 +32,8 @@
 /**
  * A simple visitor of program elements with default behavior
- * appropriate for the {@link SourceVersion#RELEASE_9 RELEASE_9}
- * and {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
+ * appropriate for source versions {@link SourceVersion#RELEASE_9
+ * RELEASE_9} through {@link SourceVersion#RELEASE_11 RELEASE_11}.
  *
  * Visit methods corresponding to {@code RELEASE_9} and earlier
--- a/src/java.compiler/share/classes/javax/lang/model/util/SimpleTypeVisitor9.java	Tue May 01 14:40:31 2018 -0700
+++ b/src/java.compiler/share/classes/javax/lang/model/util/SimpleTypeVisitor9.java	Tue May 01 17:19:18 2018 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -31,9 +31,9 @@
 import static javax.lang.model.SourceVersion.*;
 
 /**
  * A simple visitor of types with default behavior appropriate for the
  * {@link SourceVersion#RELEASE_9 RELEASE_9} and
  * {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
  *
  * Visit methods corresponding to {@code RELEASE_9} and earlier
  * language constructs call {@link #defaultAction defaultAction},
@@ -70,9 +70,10 @@
  *
  * @see SimpleTypeVisitor6
  * @see SimpleTypeVisitor7
+ * @see SimpleTypeVisitor8
  * @since 9
  */
-@SupportedSourceVersion(RELEASE_10)
+@SupportedSourceVersion(RELEASE_11)
 public class SimpleTypeVisitor9<R, P> extends SimpleTypeVisitor8<R, P> {
     /**
      * Constructor for concrete subclasses; uses {@code null} for the
@@ -31,9 +31,9 @@
 
 /**
- * A simple visitor of types with default behavior appropriate for the
- * {@link SourceVersion#RELEASE_9 RELEASE_9} and
- * {@link SourceVersion#RELEASE_10 RELEASE_10} source versions.
+ * A simple visitor of types with default behavior appropriate for
+ * source versions {@link SourceVersion#RELEASE_9 RELEASE_9} through
+ * {@link SourceVersion#RELEASE_11 RELEASE_11}.
  *
  * Visit methods corresponding to {@code RELEASE_9} and earlier
--- a/src/java.compiler/share/classes/javax/lang/model/util/TypeKindVisitor9.java	Tue May 01 14:40:31 2018 -0700
+++ b/src/java.compiler/share/classes/javax/lang/model/util/TypeKindVisitor9.java	Tue May 01 17:19:18 2018 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -32,9 +32,11 @@
 
 /**
  * A visitor of types based on their {@linkplain TypeKind kind} with
  * default behavior appropriate for the {@link SourceVersion#RELEASE_9
  * RELEASE_9} and {@link SourceVersion#RELEASE_10 RELEASE_10} source
  * versions. For {@linkplain
  * TypeMirror types} <code><i>Xyz</i></code> that may have more than one
  * kind, the <code>visit<i>Xyz</i></code> methods in this class delegate
  * to the <code>visit<i>Xyz</i>As<i>Kind</i></code> method corresponding to the
@@ -75,7 +77,7 @@
  * @see TypeKindVisitor8
  * @since 9
  */
-@SupportedSourceVersion(RELEASE_10)
+@SupportedSourceVersion(RELEASE_11)
 public class TypeKindVisitor9<R, P> extends TypeKindVisitor8<R, P> {
     /**
      * Constructor for concrete subclasses to call; uses {@code null}
@@ -32,9 +32,11 @@
 /**
  * A visitor of types based on their {@linkplain TypeKind kind} with
- * default behavior appropriate for the {@link SourceVersion#RELEASE_9
- * RELEASE_9} and {@link SourceVersion#RELEASE_10 RELEASE_10} source
- * versions. For {@linkplain
+ * default behavior appropriate for source versions {@link
+ * SourceVersion#RELEASE_9 RELEASE_9} through {@link
+ * SourceVersion#RELEASE_11 RELEASE_11}.
+ *
+ * For {@linkplain
  * TypeMirror types} <code><i>Xyz</i></code> that may have more than one
  * kind, the <code>visit<i>Xyz</i></code> methods in this class delegate